# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.4.1](https://github.com/maidsafe/safe_network/compare/test_utils-v0.4.0...test_utils-v0.4.1) - 2024-05-07

### Other
- *(versions)* sync versions with latest crates.io vs
- *(release)* sn_cli-v0.89.83/sn_client-v0.104.29/sn_networking-v0.13.33/sn_protocol-v0.15.4/sn_transfers-v0.16.4/sn_peers_acquisition-v0.2.8/sn_logging-v0.2.23/sn_faucet-v0.3.84/sn_node-v0.104.39/sn_service_management-v/sn-node-manager-v0.6.0/sn_node_rpc_client-v0.5.0/token_supplies-v0.1.44
- store test utils under a new crate
